@@ -1,25 +1,15 @@
-require 'rubygems'
 $:.unshift File.expand_path('../../lib', __FILE__)
 
-gem 'minitest', '~> 4'
-
+gem 'minitest', '~> 5'
 require 'minitest/autorun'
 require 'rake'
 require 'tmpdir'
-require File.expand_path('../file_creation', __FILE__)
 
+require_relative 'support/file_creation'
+require_relative 'support/ruby_runner'
+require_relative 'support/rakefile_definitions'
 
-begin
-  require_relative '../ruby/envutil'
-  require_relative 'support/ruby_runner'
-  require_relative 'support/rakefile_definitions'
-rescue NoMethodError, LoadError
-  # ruby 1.8
-  require 'test/support/ruby_runner'
-  require 'test/support/rakefile_definitions'
-end
-
-class Rake::TestCase < MiniTest::Unit::TestCase
+class Rake::TestCase < Minitest::Test
   include FileCreation
 
   include Rake::DSL
@@ -28,25 +18,15 @@ class Rake::TestCase < MiniTest::Unit::TestCase
     include Rake::TaskManager
   end
 
-  RUBY = defined?(EnvUtil) ? EnvUtil.rubybin : Gem.ruby
+  RUBY = Gem.ruby
 
   def setup
     ARGV.clear
 
-    test_dir = File.basename File.dirname File.expand_path __FILE__
-
-    @rake_root =
-      if test_dir == 'test'
-        # rake repository
-        File.expand_path '../../', __FILE__
-      else
-        # ruby repository
-        File.expand_path '../../../', __FILE__
-      end
-
     @verbose = ENV['VERBOSE']
 
-    @rake_exec = File.join @rake_root, 'bin', 'rake'
+    @rake_root = File.expand_path '../../', __FILE__
+    @rake_exec = File.join @rake_root, 'exe', 'rake'
     @rake_lib  = File.join @rake_root, 'lib'
     @ruby_options = ["-I#{@rake_lib}", "-I."]
 
@@ -123,5 +103,17 @@ end
     end
   end
 
+  def jruby?
+    defined?(JRUBY_VERSION)
+  end
+
+  def jruby17?
+    jruby? && (JRUBY_VERSION < '9.0.0.0')
+  end
+
+  def jruby9?
+    jruby? && (JRUBY_VERSION >= '9.0.0.0')
+  end
+
   include RakefileDefinitions
 end
